@@ -23,7 +23,7 @@ most of its responsibilities.
 
 =cut
 
-$VERSION = '0.15';
+$VERSION = '0.16';
 
 =head1 METHODS
 
@@ -313,6 +313,7 @@ sub create_multiple_parsers
     # These are the innards of a multi-parser.
     return sub {
 	my ($self, $date, @args) = @_;
+	return unless defined $date;
 
 	# Parameters common to the callbacks. Pre-prepared.
 	my %param = (
@@ -394,11 +395,7 @@ sub sort_parsers
 	{
 	    if (exists $spec->{length})
 	    {
-		croak "Cannot specify the same length twice"
-		if exists $lengths{$spec->{length}};
-
-		$lengths{$spec->{length}} =
-		    $class->create_single_parser( %$spec );
+		push @{ $lengths{$spec->{length}} }, $class->create_single_parser( %$spec );
 	    }
 	    else
 	    {
@@ -412,9 +409,29 @@ sub sort_parsers
 	}
     }
 
+    while (my ($length, $parsers) = each %lengths)
+    {
+	$lengths{$length} = $class->chain_parsers( $parsers );
+    }
+
     return ( \%lengths, \@others );
 }
 
+sub chain_parsers
+{
+    my ($self, $parsers) = @_;
+    return $parsers->[0] if @$parsers == 1;
+    return sub {
+	my $self = shift;
+	for my $parser (@$parsers)
+	{
+	    my $rv = $self->$parser( @_ );
+	    return $rv if defined $rv;
+	}
+	return undef;
+    };
+}
+
 =head2 create_parser
 
 C<create_class()> is mostly a wrapper around
